IndexCursor

Struct IndexCursor 

pub struct IndexCursor<Conf: Config> { /* private fields */ }
Index iterator cursor.

Created by IndexIter::cursor(), used by IndexIter::move_to(). Also can be built from index and DataBlock.

Same as BlockCursor, but for indices iterator.

Implementations

Source

impl<Conf: Config> IndexCursor<Conf>

pub fn start() -> Self

Constructs cursor that points to the start of the bitset.

pub fn end() -> Self

Constructs cursor that points to the end of the bitset.

Iterator moved to this cursor will always return None.